==> kubernetes-model-gatewayapi-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/ReferenceGrantListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ReferenceGrantListFluent<A extends ReferenceGrantListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,ReferenceGrant item);
  public A setToItems(Integer index,ReferenceGrant item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrant... items);
  public A addAllToItems(Collection<ReferenceGrant> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrant... items);
  public A removeAllFromItems(Collection<ReferenceGrant> items);
  public A removeMatchingFromItems(Predicate<ReferenceGrantBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ReferenceGrant> getItems();
  public List<ReferenceGrant> buildItems();
  public ReferenceGrant buildItem(Integer index);
  public ReferenceGrant buildFirstItem();
  public ReferenceGrant buildLastItem();
  public ReferenceGrant buildMatchingItem(Predicate<ReferenceGrantBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ReferenceGrantBuilder> predicate);
  public A withItems(List<ReferenceGrant> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrant... items);
  public Boolean hasItems();
  public ReferenceGrantListFluent.ItemsNested<A> addNewItem();
  public ReferenceGrantListFluent.ItemsNested<A> addNewItemLike(ReferenceGrant item);
  public ReferenceGrantListFluent.ItemsNested<A> setNewItemLike(Integer index,ReferenceGrant item);
  public ReferenceGrantListFluent.ItemsNested<A> editItem(Integer index);
  public ReferenceGrantListFluent.ItemsNested<A> editFirstItem();
  public ReferenceGrantListFluent.ItemsNested<A> editLastItem();
  public ReferenceGrantListFluent.ItemsNested<A> editMatchingItem(Predicate<ReferenceGrantBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ReferenceGrantFluent<ReferenceGrantListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/ReferenceGrantListFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ReferenceGrantListFluent<A extends ReferenceGrantListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,ReferenceGrant item);
  public A setToItems(int index,ReferenceGrant item);
  public A addToItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrant... items);
  public A addAllToItems(Collection<ReferenceGrant> items);
  public A removeFromItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrant... items);
  public A removeAllFromItems(Collection<ReferenceGrant> items);
  public A removeMatchingFromItems(Predicate<ReferenceGrantBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ReferenceGrant> getItems();
  public List<ReferenceGrant> buildItems();
  public ReferenceGrant buildItem(int index);
  public ReferenceGrant buildFirstItem();
  public ReferenceGrant buildLastItem();
  public ReferenceGrant buildMatchingItem(Predicate<ReferenceGrantBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<ReferenceGrantBuilder> predicate);
  public A withItems(List<ReferenceGrant> items);
  public A withItems(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrant... items);
  public Boolean hasItems();
  public ReferenceGrantListFluent.ItemsNested<A> addNewItem();
  public ReferenceGrantListFluent.ItemsNested<A> addNewItemLike(ReferenceGrant item);
  public ReferenceGrantListFluent.ItemsNested<A> setNewItemLike(int index,ReferenceGrant item);
  public ReferenceGrantListFluent.ItemsNested<A> editItem(int index);
  public ReferenceGrantListFluent.ItemsNested<A> editFirstItem();
  public ReferenceGrantListFluent.ItemsNested<A> editLastItem();
  public ReferenceGrantListFluent.ItemsNested<A> editMatchingItem(Predicate<ReferenceGrantBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface ItemsNested<N> extends Nested<N>,ReferenceGrantFluent<ReferenceGrantListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
